Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type DependencyGenerator ¶
DependencyGenerator takes an SCAHandle and config.Dependencies pointer and returns findings based on analysis.
type SCAFS ¶
SCAFS represents the minimum required filesystem accessors which are needed by the SCA engine.
type SCAHandle ¶
type SCAHandle interface {
// PackageName returns the name of the current package being analyzed.
PackageName() string
// RelativeNames returns the name of other packages related to the current
// package being analyzed.
RelativeNames() []string
// Version returns the version and epoch of the package being analyzed.
Version() string
// FilesystemForRelative returns a usable filesystem representing the package
// contents for a given package name.
FilesystemForRelative(pkgName string) (SCAFS, error)
// Filesystem returns a usable filesystem representing the current package.
// It is equivalent to FilesystemForRelative(PackageName()).
Filesystem() (SCAFS, error)
// Options returns a config.PackageOption struct.
Options() config.PackageOption
// BaseDependencies returns the underlying set of declared dependencies before
// the SCA engine runs.
BaseDependencies() config.Dependencies
}
SCAHandle represents all of the state necessary to analyze a package.
Click to show internal directories.
Click to hide internal directories.